/* $Id: cli.c,v 1.3 2004/04/11 05:09:36 playfair Exp $
**
** This program is free software; you can redistribute it and/or
** modify it under the terms of the GNU General Public License as
** published by the Free Software Foundation; either version 2 of the
** License, or (at your option) any later version.
**
** This program is distributed in the hope that it will be useful, but
** WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
** General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
** 02111-1307, USA.
*/

#include <stdarg.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/stat.h>

#include "playfair.h";
#include "filename.h";

#define OUTPUT_FILEXT "m4a"

int die(void *udata, u_int8_t err, ...) {
    va_list argp;
    va_start(argp, err);
    vfprintf(stderr, ERROR_MESSAGES[err], argp);
    va_end(argp);
    fprintf(stderr, "\n");

    return err;
}

void logmsg(void *udata, u_int8_t level, char *str) {
    fprintf(stderr, "playfair(%d): %s\n", level, str);
}

void status(void *udata, char *status) {
    fprintf(stderr, "%s", status);
}

static const char* ERR_USAGE =
    "USAGE: %s [-at] "
    "[-x ext] "
    "<infile1> [ [infile2] ... [infileN] ] <destdir>\n"
    "\t-a        don't copy artwork\n"
    "\t-t        don't copy tags\n"
    "\t-x [ext]  use ext as the file extension for output files"
    "\n";
int usage(char *prog) {
    fprintf(stderr, ERR_USAGE, prog);
}

int main(int argc, char *argv[]) {
    playfair_callback_t *pfcb = NULL;
    int err, opt, fileidx;
    bool copyart = TRUE;
    bool copytags = TRUE;
    char *prog = NULL, *destdir = NULL, *ext = OUTPUT_FILEXT;

    prog = argv[0];
    if (argc > 1) {
        while ((opt = getopt(argc, argv, "atx:")) != -1) {
            switch(opt) {
            case 'a':
                copyart = FALSE;
                break;
            case 't':
                copytags = FALSE;
                break;
            case 'x':
                ext = optarg;
                break;
            case 'h':
            case '?':
            default:
                return usage(prog);
            }
        }
        argc -= optind;
        argv += optind;

        /* make sure they passed the destdir */
        if (argc < 2) {
            return usage(prog);
        }

        destdir = argv[argc-1];
        /* strip any trailing file separator */
        if (destdir[strlen(destdir)-1] == FILE_SEP)
            destdir[strlen(destdir)-1] = '\0';
        /* ensure that it's a dir */
        struct stat st;
        stat(destdir, &st);
        if (!((st.st_mode & S_IFMT) == S_IFDIR)) {
            return usage(prog);
        }

        for (fileidx=0; fileidx<argc-1; ++fileidx) {
            char *infile = NULL, *outfile = NULL;
            filename_t *fn = NULL;

            infile = argv[fileidx];
            fn = malloc(sizeof(filename_t));
            parse_filename(infile, &fn);
            outfile = get_outfile(fn, destdir, ext);
/*
            printf("infile: %s, outfile: %s\n", infile, outfile);
*/

            pfcb = malloc(sizeof(playfair_callback_t));
            pfcb->log = logmsg;
            pfcb->die = die;
            pfcb->status = status;
            pfcb->user_data = NULL;

            err = convert(pfcb, infile, outfile, copytags, copyart);

            if (fn) free(fn);
            if (outfile) free(outfile);
            if (pfcb) free(pfcb);
            if (err) return err;
        }
    } else {
        return usage(prog);
    }

    return SUCCESS;
}

/* EOF */
